@@ -43,7 +43,7 @@ Usage:
             [--node_ip=<node_ip>]...
             [--node_id=<node_id>]...
             [--cluster_id=<cluster_id>]
-            [--image_file=<image_file>] [--sig_file=<sig_file>] [--pr_verify_rpt=<pr_verify_rpt] [--dont_verify_memory=<dont_verify_memory>]
+            [--image_file=<image_file>] [--comment=<comment>] [--sig_file=<sig_file>] [--pr_verify_rpt=<pr_verify_rpt] [--dont_verify_memory=<dont_verify_memory>]
             [--limit=<limit>] [--repeat=<repeat>]
             [<command>] [<args>...]
 
@@ -65,8 +65,9 @@ Options:
     --node_ip=<node_ip>         The ip of the user's VM, e.g. a ZYC2 VM.
     --node_id=<node_id>         The id (rank) of either the VPN user's VM or FPGAs.
     --cluster_id=<cluster_id>   The id of a cluster to update or extend.
-    --image_file=<image_file>      The FPGA image file to be uploaded [default: ./image.bit].
-    --sig_file=<sig_file>          An FPGA bitstream signature file containing hashes from the build process.
+    --image_file=<image_file>   The FPGA image file to be uploaded [default: ./image.bit].
+    --comment=<comment>         A comment for the FPGA image file to be uploaded [default: None].
+    --sig_file=<sig_file>       An FPGA bitstream signature file containing hashes from the build process.
     --pr_verify_rpt=<pr_verify_rpt An FPGA report containing the output of the automatically run pr_verify command.
     --dont_verify_memory=<dont_verify_memory>   If 1, don't verify the DDR4 memory during setup [default: 0].
     --limit=<limit>             The limit of get for clusters, images, instances [default: 100].
